@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use Carp;
 BEGIN {
-	our $VERSION = 'v0.1.3'; # VERSION
+	our $VERSION = 'v0.1.4'; # VERSION
 }
 use Moose;
 use namespace::autoclean;
 with qw(
 	MooseX::Traits
-	Business::CyberSource::Request
+	Business::CyberSource::Request::Role::Common
 	Business::CyberSource::Request::Role::PurchaseInfo
 );
 
@@ -125,7 +125,7 @@ Business::CyberSource::Request::Credit - CyberSource Credit Request Object
 
 =head1 VERSION
 
-version v0.1.3
+version v0.1.4
 
 =head1 ATTRIBUTES
 
@@ -193,12 +193,6 @@ This attribute is required.
 
 Additional documentation: your merchantID
 
-=head2 foreign_currency
-
-Reader: foreign_currency
-
-Type: Str
-
 =head2 client_name
 
 Reader: client_name
@@ -207,6 +201,12 @@ Type: Str
 
 This attribute is required.
 
+=head2 foreign_currency
+
+Reader: foreign_currency
+
+Type: Str
+
 =head2 reference_code
 
 Reader: reference_code
